/**
 * Class to optimize HTML scripts by deduplicating and consolidating script tags.
 */
declare class HtmlScriptsOptimizer {
    private static instance;
    private inputDirectory;
    /**
     * Private constructor to prevent direct class instantiation.
     * @param {string} inputDirectory - The directory containing HTML files to optimize.
     */
    private constructor();
    /**
     * Returns the singleton instance of HtmlScriptsOptimizer.
     * @param {string} inputDirectory - The directory containing HTML files to optimize.
     * @returns {HtmlScriptsOptimizer} The singleton instance.
     */
    static getInstance(inputDirectory: string): HtmlScriptsOptimizer;
    /**
     * Recursively reads all directories from the specified directory.
     * @param {string} dir - The directory to read subdirectories from.
     * @returns {string[]} An array of directory paths.
     */
    private readDirectoriesRecursive;
    /**
     * Reads all HTML files from the specified directory.
     * @param {string} dir - The directory to read HTML files from.
     * @returns {string[]} An array of HTML file paths.
     */
    private readHtmlFiles;
    /**
     * Extracts script tags from the given HTML content.
     * @param {string} htmlContent - The HTML content to extract script tags from.
     * @returns {string[]} An array of script tag contents.
     */
    private extractScriptTags;
    /**
     * Removes script tags from the given HTML content.
     * @param {string} htmlContent - The HTML content to remove script tags from.
     * @returns {string} The HTML content without script tags.
     */
    private removeScriptTags;
    /**
     * Inserts all script tags into the first HTML file, including both unique and duplicate tags.
     * @param {string} filePath - The path to the first HTML file to insert script tags into.
     * @param {Set<string>} scriptTags - The set of all script tag contents to insert.
     */
    private insertAllScriptTags;
    /**
     * Adds the auto-clean message to files where script tags were removed.
     * @param {string} filePath - The path to the HTML file to add the auto-clean message to.
     */
    private addAutoCleanMessage;
    /**
     * Main function to optimize scripts by deduplicating and consolidating script tags across multiple HTML files.
     * All script tags (both unique and duplicate) are moved to the first file.
     */
    run(): void;
}
export default HtmlScriptsOptimizer;
