/**
 * Checks if the required binaries are installed on the system.
 * @param binaries - The list of binaries to check.
 */
export declare function checkBinaries(binaries: string[]): void;
/**
 * Executes a command synchronously.
 * @param command - The command string to execute.
 */
export declare function executeCommandSync(command: string): void;
/**
 * Escapes special characters in a string to make it safe for inclusion in a JSON string,
 * including replacing single quotes with escaped double quotes.
 *
 * @param {string} str - The input string to be escaped.
 * @returns {string} - The escaped string, safe for inclusion in JSON.
 *
 * @example
 * const unsafeString = 'This is a "test" string with \\ special characters \n and newlines.';
 * const safeString = escapeForJSON(unsafeString);
 * console.log(safeString); // Output: This is a \"test\" string with \\ special characters \\n and newlines.
 */
export declare function escapeForJSON(str: string): string;
/**
 * Unescapes a string that was previously escaped for JSON,
 * converting escaped sequences back to their original characters.
 *
 * @param {string} str - The input string to be unescaped.
 * @returns {string} - The unescaped string.
 *
 * @example
 * const escapedString = 'This is a \\"test\\" string with \\\\ special characters \\n and newlines.';
 * const unescapedString = unescapeFromJSON(escapedString);
 * console.log(unescapedString); // Output: This is a "test" string with \ special characters \n and newlines.
 */
export declare function unescapeFromJSON(str: string): string;
/**
 * Extracts the inner code from templated blocks.
 *
 * This function takes an array of templated blocks and extracts only the inner code within the braces.
 *
 * @param {string[]} templBlocks - An array of strings, each containing a full templated block.
 * @returns {string[]} An array of strings, each containing only the inner code of the templated block.
 *
 * @example
 * const templBlocks = [
 *   "package main\\n\\nimport (\\n\\"fmt\\"\\n\\"log\\"\\n)\\ntempl AlertDemo() {\\n\\t@alertCss()\\n\\t@alert(\\"Success\\", \\"Files were successfully uploaded\\")\\n}"
 * ];
 * const result = extractInnerCode(templBlocks);
 * console.log(result);
 * // Output:
 * // [
 * //   "@alertCss()\\n  @alert(\\"Success\\", \\"Files were successfully uploaded\\")"
 * // ]
 */
export declare function extractInnerCode(templBlocks: string[]): string[];
